AdditionalAuthenticationProvider class

Describes an additional authentication provider.

Constructors

AdditionalAuthenticationProvider({AuthenticationType? authenticationType, OpenIDConnectConfig? openIDConnectConfig, CognitoUserPoolConfig? userPoolConfig})
AdditionalAuthenticationProvider.fromJson(Map<String, dynamic> json)
factory

Properties

authenticationType → AuthenticationType?
The authentication type: API key, AWS IAM, OIDC, or Amazon Cognito user pools.
final
hashCode → int
The hash code for this object.
no setterinherited
openIDConnectConfig → OpenIDConnectConfig?
The OpenID Connect configuration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userPoolConfig → CognitoUserPoolConfig?
The Amazon Cognito user pool configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited