ApiCache class

The ApiCache object.

Constructors

ApiCache({ApiCachingBehavior? apiCachingBehavior, bool? atRestEncryptionEnabled, ApiCacheStatus? status, bool? transitEncryptionEnabled, int? ttl, ApiCacheType? type})
ApiCache.fromJson(Map<String, dynamic> json)
factory

Properties

apiCachingBehavior → ApiCachingBehavior?
Caching behavior.
final
atRestEncryptionEnabled → bool?
At rest encryption flag for cache. This setting cannot be updated after creation.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ApiCacheStatus?
The cache instance status.
final
transitEncryptionEnabled → bool?
Transit encryption flag when connecting to cache. This setting cannot be updated after creation.
final
ttl → int?
TTL in seconds for cache entries.
final
type → ApiCacheType?
The cache instance type. Valid values are
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited