ApiKey class

Describes an API key.

Customers invoke AWS AppSync GraphQL API operations with API keys as an identity mechanism. There are two key versions:

da1: This version was introduced at launch in November 2017. These keys always expire after 7 days. Key expiration is managed by Amazon DynamoDB TTL. The keys ceased to be valid after February 21, 2018 and should not be used after that date.

  • ListApiKeys returns the expiration time in milliseconds.
  • CreateApiKey returns the expiration time in milliseconds.
  • UpdateApiKey is not available for this key version.
  • DeleteApiKey deletes the item from the table.
  • Expiration is stored in Amazon DynamoDB as milliseconds. This results in a bug where keys are not automatically deleted because DynamoDB expects the TTL to be stored in seconds. As a one-time action, we will delete these keys from the table after February 21, 2018.
da2: This version was introduced in February 2018 when AppSync added support to extend key expiration.
  • ListApiKeys returns the expiration time and deletion time in seconds.
  • CreateApiKey returns the expiration time and deletion time in seconds and accepts a user-provided expiration time in seconds.
  • UpdateApiKey returns the expiration time and and deletion time in seconds and accepts a user-provided expiration time in seconds. Expired API keys are kept for 60 days after the expiration time. Key expiration time can be updated while the key is not deleted.
  • DeleteApiKey deletes the item from the table.
  • Expiration is stored in Amazon DynamoDB as seconds. After the expiration time, using the key to authenticate will fail. But the key can be reinstated before deletion.
  • Deletion is stored in Amazon DynamoDB as seconds. The key will be deleted after deletion time.

Constructors

ApiKey({int? deletes, String? description, int? expires, String? id})
ApiKey.fromJson(Map<String, dynamic> json)
factory

Properties

deletes → int?
The time after which the API key is deleted. The date is represented as seconds since the epoch, rounded down to the nearest hour.
final
description → String?
A description of the purpose of the API key.
final
expires → int?
The time after which the API key expires. The date is represented as seconds since the epoch, rounded down to the nearest hour.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The API key ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited