AuthorizationConfig class

The authorization config in case the HTTP endpoint requires authorization.

Constructors

AuthorizationConfig({required AuthorizationType authorizationType, AwsIamConfig? awsIamConfig})
AuthorizationConfig.fromJson(Map<String, dynamic> json)
factory

Properties

authorizationType → AuthorizationType
The authorization type required by the HTTP endpoint.
final
awsIamConfig → AwsIamConfig?
The AWS IAM settings.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited