CachingConfig class

The caching configuration for a resolver that has caching enabled.

Constructors

CachingConfig({List<String>? cachingKeys, int? ttl})
CachingConfig.fromJson(Map<String, dynamic> json)
factory

Properties

cachingKeys → List<String>?
The caching keys for a resolver that has caching enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl → int?
The TTL in seconds for a resolver that has caching enabled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited