DataSource class

Describes a data source.

Constructors

DataSource({String? dataSourceArn, String? description, DynamodbDataSourceConfig? dynamodbConfig, ElasticsearchDataSourceConfig? elasticsearchConfig, HttpDataSourceConfig? httpConfig, LambdaDataSourceConfig? lambdaConfig, String? name, RelationalDatabaseDataSourceConfig? relationalDatabaseConfig, String? serviceRoleArn, DataSourceType? type})
DataSource.fromJson(Map<String, dynamic> json)
factory

Properties

dataSourceArn → String?
The data source ARN.
final
description → String?
The description of the data source.
final
dynamodbConfig → DynamodbDataSourceConfig?
Amazon DynamoDB settings.
final
elasticsearchConfig → ElasticsearchDataSourceConfig?
Amazon Elasticsearch Service settings.
final
hashCode → int
The hash code for this object.
no setterinherited
httpConfig → HttpDataSourceConfig?
HTTP endpoint settings.
final
lambdaConfig → LambdaDataSourceConfig?
AWS Lambda settings.
final
name → String?
The name of the data source.
final
relationalDatabaseConfig → RelationalDatabaseDataSourceConfig?
Relational database settings.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceRoleArn → String?
The AWS IAM service role ARN for the data source. The system assumes this role when accessing the data source.
final
type → DataSourceType?
The type of the data source.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited