DeltaSyncConfig class

Describes a Delta Sync configuration.

Constructors

DeltaSyncConfig({int? baseTableTTL, String? deltaSyncTableName, int? deltaSyncTableTTL})
DeltaSyncConfig.fromJson(Map<String, dynamic> json)
factory

Properties

baseTableTTL → int?
The number of minutes an Item is stored in the datasource.
final
deltaSyncTableName → String?
The Delta Sync table name.
final
deltaSyncTableTTL → int?
The number of minutes a Delta Sync log entry is stored in the Delta Sync table.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited