DynamodbDataSourceConfig class

Describes an Amazon DynamoDB data source configuration.

Constructors

DynamodbDataSourceConfig({required String awsRegion, required String tableName, DeltaSyncConfig? deltaSyncConfig, bool? useCallerCredentials, bool? versioned})
DynamodbDataSourceConfig.fromJson(Map<String, dynamic> json)
factory

Properties

awsRegion → String
The AWS Region.
final
deltaSyncConfig → DeltaSyncConfig?
The DeltaSyncConfig for a versioned datasource.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableName → String
The table name.
final
useCallerCredentials → bool?
Set to TRUE to use Amazon Cognito credentials with this data source.
final
versioned → bool?
Set to TRUE to use Conflict Detection and Resolution with this data source.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited