ElasticsearchDataSourceConfig class

Describes an Elasticsearch data source configuration.

Constructors

ElasticsearchDataSourceConfig({required String awsRegion, required String endpoint})
ElasticsearchDataSourceConfig.fromJson(Map<String, dynamic> json)
factory

Properties

awsRegion → String
The AWS Region.
final
endpoint → String
The endpoint.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited