FunctionConfiguration class

A function is a reusable entity. Multiple functions can be used to compose the resolver logic.

Constructors

FunctionConfiguration({String? dataSourceName, String? description, String? functionArn, String? functionId, String? functionVersion, String? name, String? requestMappingTemplate, String? responseMappingTemplate})
FunctionConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

dataSourceName → String?
The name of the DataSource.
final
description → String?
The Function description.
final
functionArn → String?
The ARN of the Function object.
final
functionId → String?
A unique ID representing the Function object.
final
functionVersion → String?
The version of the request mapping template. Currently only the 2018-05-29 version of the template is supported.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the Function object.
final
requestMappingTemplate → String?
The Function request mapping template. Functions support only the 2018-05-29 version of the request mapping template.
final
responseMappingTemplate → String?
The Function response mapping template.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited