GetIntrospectionSchemaResponse class

Constructors

GetIntrospectionSchemaResponse({Uint8List? schema})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → Uint8List?
The schema, in GraphQL Schema Definition Language (SDL) format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited