GraphqlApi class

Describes a GraphQL API.

Constructors

GraphqlApi({List<AdditionalAuthenticationProvider>? additionalAuthenticationProviders, String? apiId, String? arn, AuthenticationType? authenticationType, LogConfig? logConfig, String? name, OpenIDConnectConfig? openIDConnectConfig, Map<String, String>? tags, Map<String, String>? uris, UserPoolConfig? userPoolConfig, String? wafWebAclArn, bool? xrayEnabled})
GraphqlApi.fromJson(Map<String, dynamic> json)
factory

Properties

additionalAuthenticationProviders → List<AdditionalAuthenticationProvider>?
A list of additional authentication providers for the GraphqlApi API.
final
apiId → String?
The API ID.
final
arn → String?
The ARN.
final
authenticationType → AuthenticationType?
The authentication type.
final
hashCode → int
The hash code for this object.
no setterinherited
logConfig → LogConfig?
The Amazon CloudWatch Logs configuration.
final
name → String?
The API name.
final
openIDConnectConfig → OpenIDConnectConfig?
The OpenID Connect configuration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
The tags.
final
uris → Map<String, String>?
The URIs.
final
userPoolConfig → UserPoolConfig?
The Amazon Cognito user pool configuration.
final
wafWebAclArn → String?
The ARN of the AWS Web Application Firewall (WAF) ACL associated with this GraphqlApi, if one exists.
final
xrayEnabled → bool?
A flag representing whether X-Ray tracing is enabled for this GraphqlApi.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited