HttpDataSourceConfig class

Describes an HTTP data source configuration.

Constructors

HttpDataSourceConfig({AuthorizationConfig? authorizationConfig, String? endpoint})
HttpDataSourceConfig.fromJson(Map<String, dynamic> json)
factory

Properties

authorizationConfig → AuthorizationConfig?
The authorization config in case the HTTP endpoint requires authorization.
final
endpoint → String?
The HTTP URL endpoint. You can either specify the domain name or IP, and port combination, and the URL scheme must be HTTP or HTTPS. If the port is not specified, AWS AppSync uses the default port 80 for the HTTP endpoint and port 443 for HTTPS endpoints.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited