LambdaDataSourceConfig class

Describes an AWS Lambda data source configuration.

Constructors

LambdaDataSourceConfig({required String lambdaFunctionArn})
LambdaDataSourceConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lambdaFunctionArn → String
The ARN for the Lambda function.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited