ListFunctionsResponse class

Constructors

ListFunctionsResponse({List<FunctionConfiguration>? functions, String? nextToken})
ListFunctionsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

functions → List<FunctionConfiguration>?
A list of Function objects.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited