ListResolversResponse class

Constructors

ListResolversResponse({String? nextToken, List<Resolver>? resolvers})
ListResolversResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An identifier to be passed in the next request to this operation to return the next set of items in the list.
final
resolvers → List<Resolver>?
The Resolver objects.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited