LogConfig class

The CloudWatch Logs configuration.

Constructors

LogConfig({required String cloudWatchLogsRoleArn, required FieldLogLevel fieldLogLevel, bool? excludeVerboseContent})
LogConfig.fromJson(Map<String, dynamic> json)
factory

Properties

cloudWatchLogsRoleArn → String
The service role that AWS AppSync will assume to publish to Amazon CloudWatch logs in your account.
final
excludeVerboseContent → bool?
Set to TRUE to exclude sections that contain information such as headers, context, and evaluated mapping templates, regardless of logging level.
final
fieldLogLevel → FieldLogLevel
The field logging level. Values can be NONE, ERROR, or ALL.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited