OpenIDConnectConfig class

Describes an OpenID Connect configuration.

Constructors

OpenIDConnectConfig({required String issuer, int? authTTL, String? clientId, int? iatTTL})
OpenIDConnectConfig.fromJson(Map<String, dynamic> json)
factory

Properties

authTTL → int?
The number of milliseconds a token is valid after being authenticated.
final
clientId → String?
The client identifier of the Relying party at the OpenID identity provider. This identifier is typically obtained when the Relying party is registered with the OpenID identity provider. You can specify a regular expression so the AWS AppSync can validate against multiple client identifiers at a time.
final
hashCode → int
The hash code for this object.
no setterinherited
iatTTL → int?
The number of milliseconds a token is valid after being issued to a user.
final
issuer → String
The issuer for the OpenID Connect configuration. The issuer returned by discovery must exactly match the value of iss in the ID token.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited