PipelineConfig class

The pipeline configuration for a resolver of kind PIPELINE.

Constructors

PipelineConfig({List<String>? functions})
PipelineConfig.fromJson(Map<String, dynamic> json)
factory

Properties

functions → List<String>?
A list of Function objects.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited