RdsHttpEndpointConfig class

The Amazon RDS HTTP endpoint configuration.

Constructors

RdsHttpEndpointConfig({String? awsRegion, String? awsSecretStoreArn, String? databaseName, String? dbClusterIdentifier, String? schema})
RdsHttpEndpointConfig.fromJson(Map<String, dynamic> json)
factory

Properties

awsRegion → String?
AWS Region for RDS HTTP endpoint.
final
awsSecretStoreArn → String?
AWS secret store ARN for database credentials.
final
databaseName → String?
Logical database name.
final
dbClusterIdentifier → String?
Amazon RDS cluster ARN.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
Logical schema name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited