RelationalDatabaseDataSourceConfig class

Describes a relational database data source configuration.

Constructors

RelationalDatabaseDataSourceConfig({RdsHttpEndpointConfig? rdsHttpEndpointConfig, RelationalDatabaseSourceType? relationalDatabaseSourceType})
RelationalDatabaseDataSourceConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
rdsHttpEndpointConfig → RdsHttpEndpointConfig?
Amazon RDS HTTP endpoint settings.
final
relationalDatabaseSourceType → RelationalDatabaseSourceType?
Source type for the relational database.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited