Resolver class

Describes a resolver.

Constructors

Resolver({CachingConfig? cachingConfig, String? dataSourceName, String? fieldName, ResolverKind? kind, PipelineConfig? pipelineConfig, String? requestMappingTemplate, String? resolverArn, String? responseMappingTemplate, SyncConfig? syncConfig, String? typeName})
Resolver.fromJson(Map<String, dynamic> json)
factory

Properties

cachingConfig → CachingConfig?
The caching configuration for the resolver.
final
dataSourceName → String?
The resolver data source name.
final
fieldName → String?
The resolver field name.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → ResolverKind?
The resolver type.
final
pipelineConfig → PipelineConfig?
The PipelineConfig.
final
requestMappingTemplate → String?
The request mapping template.
final
resolverArn → String?
The resolver ARN.
final
responseMappingTemplate → String?
The response mapping template.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncConfig → SyncConfig?
The SyncConfig for a resolver attached to a versioned datasource.
final
typeName → String?
The resolver type name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited