UserPoolConfig class

Describes an Amazon Cognito user pool configuration.

Constructors

UserPoolConfig({required String awsRegion, required DefaultAction defaultAction, required String userPoolId, String? appIdClientRegex})
UserPoolConfig.fromJson(Map<String, dynamic> json)
factory

Properties

appIdClientRegex → String?
A regular expression for validating the incoming Amazon Cognito user pool app client ID.
final
awsRegion → String
The AWS Region in which the user pool was created.
final
defaultAction → DefaultAction
The action that you want your GraphQL API to take when a request that uses Amazon Cognito user pool authentication doesn't match the Amazon Cognito user pool configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userPoolId → String
The user pool ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited